@@ -52,6 +52,8 @@ MONITORLOGLOCATION = os.path.join(os.sep,'var','log','submit','monitors')
 MONITORLOGFILENAME = "monitorTunnel.log"
 APPLICATIONLOGGER  = logging.getLogger('') 
 
+PIDFILE = os.path.join(os.sep,'var','run','submit','submit-tunnel.pid')
+
 CONFIGURATIONDIRECTORY   = os.path.join(os.sep,'etc','submit')
 DAEMONSCONFIGURATIONFILE = 'daemons.conf'
 INFOSCONFIGURATIONFILE   = 'infos.conf'
@@ -118,6 +120,25 @@ def daemonize(fdLogFile):
    time.sleep(2)
 
 
+def writePidFile(pidFile):
+   pidSaved = False
+   try:
+      fpPid = open(pidFile,'w')
+      try:
+         fpPid.write("%d\n" % (os.getpid()))
+      except (IOError,OSError):
+         APPLICATIONLOGGER.log(logging.ERROR,getLogMessage("Unable to write pid (%d) to %s" % (os.getpid(),pidFile)))
+      else:
+         pidSaved = True
+      finally:
+         fpPid.close()
+   except:
+      APPLICATIONLOGGER.log(logging.ERROR,getLogMessage("Unable to open pid (%d) to %s" % (os.getpid(),pidFile)))
+
+   if not pidSaved:
+      os._exit(os.EX_CANTCREAT)
+
+
 class MonitorTunnel:
    def __init__(self,
                 installedDirectory,
@@ -256,6 +277,8 @@ if __name__ == '__main__':
    fdLogFile = openLogger(MONITORLOGLOCATION,MONITORLOGFILENAME)
    daemonize(fdLogFile)
 
+   writePidFile(PIDFILE)
+
    __monitorTunnel__ = MonitorTunnel(MONITORROOT,CONFIGURATIONDIRECTORY,
                                                  DAEMONSCONFIGURATIONFILE,INFOSCONFIGURATIONFILE,
                                                  SSHIDENTITY)
